/*
 * File Archive Library
 * Copyright (C) 2000-2001 Patrizio Bruno <patrizio@dada.it>
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation; either
 *    version 2.1 of the License, or (at your option) any later version.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 *
 *    You should have received a copy of the GNU Lesser General Public
 *    License along with this library; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *    Read the file LICENSE for more.
 *
 */

/*
 * $Log: far.h,v $
 * Revision 3.2  2001/06/06 11:46:24  rusty
 * *** empty log message ***
 *
 * Revision 3.1  2001/05/31 11:38:02  rusty
 *
 * code clean
 *
 * Revision 3.0  2001/05/31 11:34:20  rusty
 *
 * new version
 *
 * Revision 2.2  2001/05/30 14:47:43  rusty
 * *** empty log message ***
 *
 * Revision 2.1  2001/05/28 14:50:19  rusty
 * *** empty log message ***
 *
 * Revision 2.0  2001/05/28 12:13:53  rusty
 *
 * changing revision code for this release of the algorithm
 *
 * Revision 1.14  2001/05/28 12:08:42  rusty
 *
 * some ifdef/define/typdef corrected
 *
 * Revision 1.13  2001/05/28 11:44:33  rusty
 *
 * fixed a bug handling entry_info.st_* on solaris
 *
 * Revision 1.12  2001/05/28 11:12:19  rusty
 *
 * struct stat entry_info has been replaced by struct far_stat
 * a portable version of the stat structure
 *
 * Revision 1.11  2001/05/21 11:08:58  rusty
 *
 * some code clean
 *
 * Revision 1.10  2001/05/21 11:06:31  rusty
 *
 * byte ordering fixed
 *
 * Revision 1.9  2001/05/16 16:08:17  rusty
 * *** empty log message ***
 *
 * Revision 1.8  2001/05/16 11:39:11  rusty
 *
 * code fixes
 *
 * Revision 1.7  2001/05/16 11:04:57  rusty
 *
 * some debug code removed
 * added a function displaying the internal version of the library: far_version() in utils.c
 *
 * Revision 1.6  2001/05/16 10:50:39  rusty
 *
 * fixed the checksum control on archive expand
 * some little code clean up
 *
 * Revision 1.5  2000/09/21 11:27:44  rusty
 *
 * bug fixes
 *
 * Revision 1.4  2000/09/20 17:43:07  rusty
 *
 * why checksums of big files seem to be corrupted?
 *
 * Revision 1.3  2000/09/20 14:10:22  rusty
 *
 * First working (basic) release
 *
 */

#ifndef	_FAR_H_
#define	_FAR_H_

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <regex.h>
#include <dirent.h>
#include <sys/stat.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <utime.h>
#include <stdarg.h>
#include <netinet/in.h>
#if	(defined(_sun_) || defined(__sun__))
#	include <inttypes.h>
#endif

#include "md5.h"

#define	FAR_VERSION \
"$Revision: 3.2 $"
#define	FARVER_ALPHA	NULL
#define	FARVER_BETA	NULL

regex_t preg;

#if (defined(_sun) || defined(__sun__))
typedef	uint64_t	u_int64_t;
#endif


struct far_stat
{
	unsigned	int	fst_uid,
				fst_gid;
	unsigned	int	fst_mode;
	unsigned	int	__pad;
	u_int64_t		fst_atime,
				fst_mtime;
	u_int64_t		fst_rdev;
	u_int64_t		fst_size;
};

typedef struct _far_info_
{
	struct	_far_info_	*next,
				*prev;
	char			path[1024],
				link_path[1024];
	struct	far_stat	entry_info;
	unsigned	char	chksum[16];
	size_t			offset;
	int			__pad;
} FAR_INFO;

typedef	struct	_far_info_big
{
	char			path[1024],
				link_path[1024];
	struct	far_stat	entry_info;
	unsigned	char	chksum;
	size_t			offset;
	int			__pad;
} far_big_t;

typedef	struct	_far_info_compact
{
	size_t			offset;
	size_t			pathlen;
	size_t			lpathlen;
	struct	far_stat	entry_info;
} far_little_t;

#define	far_regexp_set(x)	regcomp(&preg, x, REG_EXTENDED|REG_NOSUB)

void *far_create(char *, char *, size_t *);
int far_extract(unsigned char *, unsigned int);
int far_file(const char *, unsigned char *, unsigned int);

#endif	/* _FAR_H_ */
